@@ -145,6 +145,24 @@ namespace LongoMatch
 		}
 		
 		#region Properties
+		static public Image FieldBackground {
+			get {
+				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.FIELD_BACKGROUND));
+			}
+		}
+		
+		static public Image HalfFieldBackground {
+			get {
+				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.HALF_FIELD_BACKGROUND));
+			}
+		}
+		
+		static public Image GoalBackground {
+			get {
+				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.GOAL_BACKGROUND));
+			}
+		}
+		
 		public static bool FastTagging {
 			get {
 				return state.fastTagging;
