@@ -284,6 +284,14 @@ gst_nle_source_push_buffer (GstNleSource * nlesrc, GstBuffer * buf,
 
   item = (GstNleSrcItem *) g_list_nth_data (nlesrc->queue, nlesrc->index);
   buf_ts = GST_BUFFER_TIMESTAMP (buf);
+
+  if (buf_ts < item->start) {
+    GST_LOG_OBJECT (nlesrc, "Discard early %s buffer with ts: %"
+      GST_TIME_FORMAT" start: %" GST_TIME_FORMAT, is_audio ? "audio" : "video",
+      GST_TIME_ARGS (buf_ts), GST_TIME_ARGS (item->start));
+    gst_buffer_unref (buf);
+    return GST_FLOW_OK;
+  }
   buf_rel_ts = buf_ts - item->start;
 
   g_mutex_lock (&nlesrc->stream_lock);
@@ -634,7 +642,8 @@ gst_nle_source_next (GstNleSource * nlesrc)
   GST_DEBUG_OBJECT (nlesrc, "Start ts:%" GST_TIME_FORMAT,
       GST_TIME_ARGS (nlesrc->start_ts));
   gst_element_set_state (nlesrc->decoder, GST_STATE_PLAYING);
-  ret = gst_element_get_state (nlesrc->decoder, &state, NULL, 2 * GST_SECOND);
+  ret = gst_element_get_state (nlesrc->decoder, &state,
+      NULL, 5 * GST_SECOND);
   if (ret == GST_STATE_CHANGE_FAILURE) {
     GST_WARNING_OBJECT (nlesrc, "Error changing state, selecting next item.");
     gst_nle_source_check_eos (nlesrc);
